@@ -13,11 +13,12 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import imp
+import importlib
 import inspect
 from unittest import mock
 
-import pkg_resources
+import stevedore
+from stevedore import extension
 
 from novaclient import client
 from novaclient.tests.unit import utils
@@ -27,16 +28,21 @@ class DiscoverTest(utils.TestCase):
 
     def test_discover_via_entry_points(self):
 
-        def mock_iter_entry_points(group):
-            if group == 'novaclient.extension':
-                fake_ep = mock.Mock()
-                fake_ep.name = 'foo'
-                fake_ep.module = imp.new_module('foo')
-                fake_ep.load.return_value = fake_ep.module
-                return [fake_ep]
+        def mock_mgr():
+            fake_ep = mock.Mock()
+            fake_ep.name = 'foo'
+            module_spec = importlib.machinery.ModuleSpec('foo', None)
+            fake_ep.module = importlib.util.module_from_spec(module_spec)
+            fake_ep.load.return_value = fake_ep.module
+            fake_ext = extension.Extension(
+                name='foo',
+                entry_point=fake_ep,
+                plugin=fake_ep.module,
+                obj=None,
+            )
+            return stevedore.ExtensionManager.make_test_instance([fake_ext])
 
-        @mock.patch.object(pkg_resources, 'iter_entry_points',
-                           mock_iter_entry_points)
+        @mock.patch.object(client, '_make_discovery_manager', mock_mgr)
         def test():
             for name, module in client._discover_via_entry_points():
                 self.assertEqual('foo', name)
@@ -47,10 +53,14 @@ class DiscoverTest(utils.TestCase):
     def test_discover_extensions(self):
 
         def mock_discover_via_python_path():
-            yield 'foo', imp.new_module('foo')
+            module_spec = importlib.machinery.ModuleSpec('foo', None)
+            module = importlib.util.module_from_spec(module_spec)
+            yield 'foo', module
 
         def mock_discover_via_entry_points():
-            yield 'baz', imp.new_module('baz')
+            module_spec = importlib.machinery.ModuleSpec('baz', None)
+            module = importlib.util.module_from_spec(module_spec)
+            yield 'baz', module
 
         @mock.patch.object(client,
                            '_discover_via_python_path',
